@@ -258,62 +258,3 @@ mod map {
         }
     }
 }
-
-///
-/// Trait that captures all user defined plot formatting. This includes:
-///
-/// * The distribution of ticks on each axis,
-///
-/// * The formatting of:
-///     * title
-///     * xname
-///     * yname
-///     * xticks
-///     * yticks
-///
-pub(crate) trait BaseFmtAndTicks {
-    type X: PlotNum;
-    type Y: PlotNum;
-    type Fmt: BaseFmt<X = Self::X, Y = Self::Y>;
-    type XI: IntoIterator<Item = Self::X>;
-    type YI: IntoIterator<Item = Self::Y>;
-    fn gen(self) -> (Self::Fmt, TickInfo<Self::XI>, TickInfo<Self::YI>);
-}
-
-pub(crate) trait OnePlotFmt {
-    type Item;
-    type It: Iterator<Item = Self::Item>;
-    fn get_iter(&mut self) -> Self::It;
-    fn plot_type(&mut self) -> crate::PlotMetaType;
-    fn fmt(&mut self, writer: &mut dyn fmt::Write) -> fmt::Result;
-}
-
-pub(crate) trait AllPlotFmt {
-    type Item2;
-    type InnerIt: OnePlotFmt<Item = Self::Item2>;
-    type It: Iterator<Item = Self::InnerIt>;
-    fn iter(self) -> Self::It;
-}
-
-pub(crate) trait BaseAndPlotsFmt {
-    type X: PlotNum;
-    type Y: PlotNum;
-    type A: BaseFmtAndTicks<X = Self::X, Y = Self::Y>;
-    type B: AllPlotFmt<Item2 = (Self::X, Self::Y)>;
-    fn gen(self) -> (Self::A, Self::B);
-}
-
-#[derive(Copy, Clone, Debug)]
-pub(crate) enum PlotType {
-    Scatter,
-    Line,
-    Histo,
-    LineFill,
-    LineFillRaw,
-}
-
-#[derive(Copy, Clone, Debug)]
-pub(crate) enum PlotMetaType {
-    Plot(PlotType),
-    Text,
-}
